import { Fragment, lazy } from "react";
import DynamicStyle from "../common/wrapper/DynamicStyle";

const CertificateActiveProduct = lazy(() =>
  import("../sections/forPages/CertificateActiveProduct")
);
const NarrowBanner = lazy(() => import("../sections/forPages/NarrowBanner"));

const MapSection = lazy(() => import("../sections/forPages/MapSection"));
const ContactUsSection = lazy(() =>
  import("../sections/forPages/ContactUsSection")
);
const SendMessageSection = lazy(() =>
  import("../sections/forPages/SendMessageSection")
);
const RichTextSection = lazy(() =>
  import("../sections/forPages/RichTextSection")
);
const MainBannerSingleImageSection = lazy(() =>
  import("../sections/forPages/MainBannerSingleImageSection")
);
const CertificatesList = lazy(() =>
  import("../sections/forPages/CertificatesList")
);
const ServicesListSection = lazy(() =>
  import("../sections/forPages/ServicesListSection")
);
const BennefitsListSection = lazy(() =>
  import("../sections/forPages/BennefitsListSection")
);

const FaqSection = lazy(() => import("../sections/forPages/FaqSection"));
const ArticlesList = lazy(() => import("../sections/forPages/ArticlesList"));
const Quiz = lazy(() => import("../sections/forPages/Quiz"));

const SimpleCommentsSection = lazy(() =>
  import("../sections/forPages/SimpleCommentsSection")
);

const sectionLib = {
  "contact-us": ContactUsSection,
  "rich-text": RichTextSection,
  "main-banner-single-image": MainBannerSingleImageSection,
  "certificates-list": CertificatesList,
  "services-list": ServicesListSection,
  "benefits-list": BennefitsListSection,
  "simple-comments": SimpleCommentsSection,
  "narrow-banner": NarrowBanner,
  "product-active-list": CertificateActiveProduct,
  faq: FaqSection,
  map: MapSection,
  sendMessage: SendMessageSection,
  "articles-list": ArticlesList,
  quiz: Quiz,
};

const SectionRenderer = ({ sections }) => {
  // console.log(sections);
  if (!sections) return null;
  return (
    <div className="w-full flex flex-col ">
      {sections.map((section, sectionIndex) => {
        if (section.active) {
          const Component = sectionLib[section.name];

          return (
            <DynamicStyle
              key={sectionIndex}
              mobile={section.content.mobileMarginTop}
              tablet={section.content.tabletMarginTop}
              desktop={section.content.marginTop}
              isActive={section.active}
            >
              {Component && <Component content={section.content} />}
            </DynamicStyle>
          );
        } else {
          return null;
        }
      })}
    </div>
  );
};

export default SectionRenderer;
